@@ -13,8 +13,8 @@ unix_month = 2678400000
 
 
 class LoadDataKline:
-    def __init__(self, exchange: Exchange, *args, **kwargs):
-        self.table = KlineData(source=exchange.name)
+    def __init__(self, exchange: Exchange, suffix="com", *args, **kwargs):
+        self.table = KlineData(prefix=exchange.name, suffix=suffix)
         self.exchange = exchange
         super(LoadDataKline, self).__init__(*args, **kwargs)
 
